# About `gsxform`

## Motivation

`gsxform` is an effort to provide readable, flexible and computationally efficient
implementations of graph scattering transform algorithms.

More explicitly, this is a project started as to assist research into the effectiveness
of graph scattering transforms, and models constructed with these transforms as in
contest with more conventional graph neural network approaches.

## Licence 
The original code of this repository is released under the
[BSD 3.0-Clause Licence](https://github.com/armaank/gsxform/blob/main/LICENSE).
Modifications, adaptations and derivative work is encouraged!
